==> gmime-2.4.22-i486-70.1.txz: usr/src/gmime-2.4.22/build-gmime.sh <==
#!/bin/sh
#
# source: http://ftp.gnome.org/pub/gnome/sources/gmime/2.4/gmime-2.4.22.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='gmime'
softversion='2.4.22'
packageversion='70.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --disable-static

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING PORTING README TODO $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/gmime-2.4 html )

mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler------------------------------------------------------|
gmime: gmime-is MIME parsing library
gmime:
gmime: GMime is a set of utilities for parsing and creating messages using
gmime: the Multipurpose Internet Mail Extension (MIME) as defined by many
gmime: Internet RFCs.
gmime:
gmime: Jeffrey Stedfast is the author of GMime.
gmime:
gmime:
gmime:
gmime:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz >$package.md5

==> gmime-2.6.7-i486-72.1.txz: usr/src/gmime-2.6.7/build-gmime.sh <==
#!/bin/sh
#
# source: http://ftp.gnome.org/pub/gnome/sources/gmime/2.6/gmime-2.6.7.tar.xz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft="gmime"
softversion="2.6.7"
packageversion="72.1"

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --disable-static \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j6
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING PORTING README TODO $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion ; ln -s /usr/share/gtk-doc/html/gmime-2.4 html )

mkdir -p $dest/install
cat << EOF > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler------------------------------------------------------|
gmime: gmime-is MIME parsing library
gmime:
gmime: GMime is a set of utilities for parsing and creating messages using
gmime: the Multipurpose Internet Mail Extension (MIME) as defined by many
gmime: Internet RFCs.
gmime:
gmime: Jeffrey Stedfast is the author of GMime.
gmime:
gmime:
gmime:
gmime:
EOF

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging
cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz >$package.md5
